@@ -6,12 +6,12 @@ from .base import Base
 
 
 class News(Base):
-    def __init__(self, index):
-        """Returns Avanza news
+    """Returns Avanza news
 
-        Args:
-            index (int): The amount of news to be returned
-        """
+    Args:
+        index (int): The amount of news to be returned
+    """
+    def __init__(self, index):
         super().__init__()
         url = f"{BASE_URL}{constants['paths']['NEWS']}".format(index)
         self.data = self._request(url)
@@ -47,7 +47,8 @@ class News(Base):
         string = ""
         for news in self.data['news']:
             string += f"\033[1mTitle:\033[0m {news['title']}\n"
-            time = datetime.strptime(news['publishDateTime'], '%Y-%m-%dT%H:%M:%S%z')
+            time = datetime.strptime(news['publishDateTime'],
+                                     '%Y-%m-%dT%H:%M:%S%z')
             string += f"\033[1mPublished:\033[0m {time:%d-%m-%Y %H:%M}\n"
             string += f"\033[1mUrl:\033[0m {BASE_URL}{news['url']}.html\n"
             string += f"\033[1mText:\033[0m {news['text']}\n"
